@@ -16,6 +16,12 @@ DisplayOneTrial <- function(rr, N = 100, ptSize = 1) {
 
 runSampleExperiment <- function(DisplayTrial, DefineStimuli, 
 		NumTrials = NULL, DisplaySize = 10, ...) {
+	cat("Four stimuli are presented on each trial \n")
+	cat("If you perceive a greater difference between  \n")
+	cat("  the lower two than the upper two, enter a 1. \n")
+	cat("If you perceive a greater difference between \n")
+	cat("  the upper pair, enter a 2. \n")
+	cat("If you want to quit, enter a 0 \n\n\n")
 	stim <- do.call(DefineStimuli, list())
 	NumStimuli <- length(stim)
 	allTrials <- t(combn(seq(NumStimuli), 4))
@@ -30,20 +36,22 @@ runSampleExperiment <- function(DisplayTrial, DefineStimuli,
 				 		"x11", windows = "windows")
 	do.call(dispdev, list(width = DisplaySize, 
 						  height = DisplaySize))				 
-#						quartz(width = DisplaySize, 
-#							height = DisplaySize) else 
-#						x11(width = DisplaySize, 
-#							height = DisplaySize),
-#				windows = windows(width = DisplaySize, 
-#					height = DisplaySize))
 	NT <- if (missing(NumTrials)) seq(nrow(trial)) else
 			seq(NumTrials)
 	for (tr in NT) {
 		par(mfrow = c(2, 2))
 			do.call(DisplayTrial, 
 				list(stim[trial[tr, ]], ...))
-		cat("\n", tr,  "\nLower or Upper Pair (1, 2): ", "\n")
-		resp[tr] <- scan(n = 1)
+		cat("\n", tr, "\nEnter 1 (Lower) or 2 (Upper) Pair: ", "\n")
+        ii <- 0
+       while (!(resp[tr] %in% 0:2)) {
+       			if (ii > 0) print ("Enter only 1, 2 or 0 to quit")
+        	 	resp[tr] <- scan(n = 1)
+        	 	ii <- ii + 1
+        	 	resp[tr] }
+        if (resp[tr] == 0) break
+#		cat("\n", tr,  "\nLower or Upper Pair (1, 2): ", "\n")
+#		resp[tr] <- scan(n = 1)
 	}
 	graphics.off()
 
